@@ -102,6 +102,8 @@ class BaseObject(_BaseEstimator):
         # run init with a copy of parameters self had at the start
         self.__init__(**params)
 
+        return self
+
     @classmethod
     def get_class_tags(cls):
         """Get class tags from estimator class and all its parent classes.
@@ -437,6 +439,46 @@ class BaseObject(_BaseEstimator):
 
         return composite
 
+    def _components(self, base_class=None):
+        """Retirn references to all state changing BaseObject type attributes.
+
+        This *excludes* the blue-print-like components passed in the __init__.
+
+        Caution: this method returns *references* and not *copies*.
+            Writing to the reference will change the respective attribute of self.
+
+        Parameters
+        ----------
+        base_class : class, optional, default=None, must be subclass of BaseObject
+            if not None, sub-sets return dict to only descendants of base_class
+
+        Returns
+        -------
+        dict with key = attribute name, value = reference to that BaseObject attribute
+        dict contains all attributes of self that inherit from BaseObjects, and:
+            whose names do not contain the string "__", e.g., hidden attributes
+            are not class attributes, and are not hyper-parameters (__init__ args)
+        """
+        if base_class is None:
+            base_class = BaseObject
+        if base_class is not None and not inspect.isclass(base_class):
+            raise TypeError(f"base_class must be a class, but found {type(base_class)}")
+        if base_class is not None and not issubclass(base_class, BaseObject):
+            raise TypeError("base_class must be a subclass of BaseObject")
+
+        # retrieve parameter names to exclude them later
+        param_names = self.get_params(deep=False).keys()
+
+        # retrieve all attributes that are BaseObject descendants
+        attrs = [attr for attr in dir(self) if "__" not in attr]
+        cls_attrs = [attr for attr in dir(type(self))]
+        self_attrs = set(attrs).difference(cls_attrs).difference(param_names)
+
+        comp_dict = {x: getattr(self, x) for x in self_attrs}
+        comp_dict = {x: y for (x, y) in comp_dict.items() if isinstance(y, base_class)}
+
+        return comp_dict
+
 
 class TagAliaserMixin:
     """Mixin class for tag aliasing and deprecation of old tags.
@@ -460,11 +502,19 @@ class TagAliaserMixin:
 
     # dictionary of aliases
     # key = old tag; value = new tag, aliased by old tag
-    alias_dict = {"fit-in-transform": "fit_is_empty", "fit-in-predict": "fit_is_empty"}
+    alias_dict = {
+        "fit-in-transform": "fit_is_empty",
+        "fit-in-predict": "fit_is_empty",
+        "capability:early_prediction": "",
+    }
 
     # dictionary of removal version
     # key = old tag; value = version in which tag will be removed, as string
-    deprecate_dict = {"fit-in-transform": "0.12.0", "fit-in-predict": "0.12.0"}
+    deprecate_dict = {
+        "fit-in-transform": "0.12.0",
+        "fit-in-predict": "0.12.0",
+        "capability:early_prediction": "0.13.0",
+    }
 
     def __init__(self):
         super(TagAliaserMixin, self).__init__()
@@ -613,7 +663,7 @@ class TagAliaserMixin:
             if tag_name in cls.alias_dict.keys():
                 version = cls.deprecate_dict[tag_name]
                 new_tag = cls.alias_dict[tag_name]
-                msg = f'tag "{tag_name}" is will be removed in sktime version {version}'
+                msg = f'tag "{tag_name}" will be removed in sktime version {version}'
                 if new_tag != "":
                     msg += (
                         f' and replaced by "{new_tag}", please use "{new_tag}" instead'
