@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 """HIVE-COTE v2 test code."""
 
+from sktime._contrib.vector_classifiers._rotation_forest import RotationForest
 from sktime.classification.hybrid import HIVECOTEV2
-from sktime.contrib.vector_classifiers._rotation_forest import RotationForest
 from sktime.datasets import load_unit_test
 
 
