@@ -82,7 +82,7 @@ def load_UCR_UEA_dataset(name, split=None, return_X_y=True, extract_path=None):
 
     Returns
     -------
-    X: pandas DataFrame
+    X: pd.DataFrame
         The time series data for the problem with n_cases rows and either
         n_dimensions or n_dimensions+1 columns. Columns 1 to n_dimensions are the
         series associated with each case. If return_X_y is False, column
@@ -90,13 +90,17 @@ def load_UCR_UEA_dataset(name, split=None, return_X_y=True, extract_path=None):
     y: numpy array, optional
         The class labels for each case in X, returned separately if return_X_y is
         True, or appended to X if False
+
+    Examples
+    --------
+    >>> from sktime.datasets import load_UCR_UEA_dataset
+    >>> X, y = load_UCR_UEA_dataset(name="Yoga")
     """
     return _load_dataset(name, split, return_X_y, extract_path)
 
 
 def load_plaid(split=None, return_X_y=True):
-    """
-    Load the PLAID time series classification problem and returns X and y.
+    """Load the PLAID time series classification problem and returns X and y.
 
     Example of a univariate problem with unequal length series.
 
@@ -111,18 +115,21 @@ def load_plaid(split=None, return_X_y=True):
 
     Returns
     -------
-    X: pandas DataFrame with m rows and c columns
+    X: pd.DataFrame with m rows and c columns
         The time series data for the problem with m cases and c dimensions
     y: numpy array The class labels for each case in X
 
+    Examples
+    --------
+    >>> from sktime.datasets import load_plaid
+    >>> X, y = load_plaid()
     """
     name = "PLAID"
     return _load_dataset(name, split, return_X_y)
 
 
 def load_gunpoint(split=None, return_X_y=True):
-    """
-    Load the GunPoint time series classification problem and returns X and y.
+    """Load the GunPoint time series classification problem and returns X and y.
 
     Parameters
     ----------
@@ -135,11 +142,16 @@ def load_gunpoint(split=None, return_X_y=True):
 
     Returns
     -------
-    X: pandas DataFrame with m rows and c columns
+    X: pd.DataFrame with m rows and c columns
         The time series data for the problem with m cases and c dimensions
     y: numpy array
         The class labels for each case in X
 
+    Examples
+    --------
+    >>> from sktime.datasets import load_gunpoint
+    >>> X, y = load_gunpoint()
+
     Notes
     -----
     Dimensionality:     univariate
@@ -173,8 +185,7 @@ def load_gunpoint(split=None, return_X_y=True):
 
 
 def load_osuleaf(split=None, return_X_y=True):
-    """
-    Load the OSULeaf time series classification problem and returns X and y.
+    """Load the OSULeaf time series classification problem and returns X and y.
 
     Parameters
     ----------
@@ -188,11 +199,16 @@ def load_osuleaf(split=None, return_X_y=True):
 
     Returns
     -------
-    X: pandas DataFrame with m rows and c columns
+    X: pd.DataFrame with m rows and c columns
         The time series data for the problem with m cases and c dimensions
     y: numpy array
         The class labels for each case in X
 
+    Examples
+    --------
+    >>> from sktime.datasets import load_osuleaf
+    >>> X, y = load_osuleaf()
+
     Notes
     -----
     Dimensionality:     univariate
@@ -216,8 +232,7 @@ def load_osuleaf(split=None, return_X_y=True):
 
 
 def load_italy_power_demand(split=None, return_X_y=True):
-    """
-    Load ItalyPowerDemand time series classification problem.
+    """Load ItalyPowerDemand time series classification problem.
 
     Parameters
     ----------
@@ -231,11 +246,16 @@ def load_italy_power_demand(split=None, return_X_y=True):
 
     Returns
     -------
-    X: pandas DataFrame with m rows and c columns
+    X: pd.DataFrame with m rows and c columns
         The time series data for the problem with m cases and c dimensions
     y: numpy array
         The class labels for each case in X
 
+    Examples
+    --------
+    >>> from sktime.datasets import load_italy_power_demand
+    >>> X, y = load_italy_power_demand()
+
     Notes
     -----
     Dimensionality:     univariate
@@ -255,48 +275,61 @@ def load_italy_power_demand(split=None, return_X_y=True):
     return _load_dataset(name, split, return_X_y)
 
 
-def load_unit_test(split=None, return_X_y=True):
+def load_unit_test(split=None, return_X_y=True, return_type=None):
     """
-    Load UnitTest time series classification problem.
+    Load UnitTest data.
 
-    This problem is a stripped down version of the ChinaTown problem that is used in
-    correctness tests for classification.
+    This is an equal length univariate time series classification problem. It is a
+    stripped down version of the ChinaTown problem that is used in correctness tests
+    for classification. It loads a two class classification problem with number of
+    cases, n, where n = 42 (if split is None) or 20/22 (if split is "train"/"test")
+    of series length m = 24
 
     Parameters
     ----------
     split: None or str{"train", "test"}, optional (default=None)
-        Whether to load the train or test partition of the problem. By
-        default it loads both.
+        Whether to load the train or test partition of the problem. By default it
+        loads both.
     return_X_y: bool, optional (default=True)
-        If True, returns (features, target) separately instead of a single
-        dataframe with columns for
-        features and the target.
+        If True, returns (features, target) separately instead of a concatenated data
+        structure.
+    return_type: None or str{"numpy2d", "numpyflat", "numpy3d", "nested_univ"},
+        optional (default=None). Controls the returned data structure.
 
     Returns
     -------
-    X: pandas DataFrame with m rows and c columns
-        The time series data for the problem with m cases and c dimensions
-    y: numpy array
-        The class labels for each case in X
+    X:  The time series data for the problem. If return_type is either
+        "numpy2d"/"numpyflat", it returns 2D numpy array of shape (n,m), if "numpy3d" it
+        returns 3D numpy array of shape (n,1,m) and if "nested_univ" or None it returns
+        a nested pandas DataFrame of shape (n,1), where each cell is a pd.Series of
+        length m.
+    y: (optional) numpy array shape (n,1). The class labels for each case in X.
+        If return_X_y is False, y is appended to X.
+
+    Examples
+    --------
+    >>> from sktime.datasets import load_unit_test
+    >>> X, y = load_unit_test()
 
     Details
     -------
-    This is the Chinatown problem with a smaller test set, useful for rapid tests. See
-    http://timeseriesclassification.com/description.php?Dataset=Chinatown
-    for the full dataset
+    This is the Chinatown problem with a smaller test set, useful for rapid tests.
     Dimensionality:     univariate
     Series length:      24
     Train cases:        20
     Test cases:         22 (full dataset has 345)
     Number of classes:  2
+
+     See
+    http://timeseriesclassification.com/description.php?Dataset=Chinatown
+    for the full dataset
     """
     name = "UnitTest"
-    return _load_provided_dataset(name, split, return_X_y)
+    return _load_provided_dataset(name, split, return_X_y, return_type)
 
 
 def load_japanese_vowels(split=None, return_X_y=True):
-    """
-    Load the JapaneseVowels time series classification problem.
+    """Load the JapaneseVowels time series classification problem.
 
     Example of a multivariate problem with unequal length series.
 
@@ -311,11 +344,16 @@ def load_japanese_vowels(split=None, return_X_y=True):
 
     Returns
     -------
-    X: pandas DataFrame with m rows and c columns
+    X: pd.DataFrame with m rows and c columns
         The time series data for the problem with m cases and c dimensions
     y: numpy array
         The class labels for each case in X
 
+    Examples
+    --------
+    >>> from sktime.datasets import load_japanese_vowels
+    >>> X, y = load_japanese_vowels()
+
     Notes
     -----
     Dimensionality:     multivariate, 12
@@ -362,11 +400,16 @@ def load_arrow_head(split=None, return_X_y=True, return_type="nested_univ"):
 
     Returns
     -------
-    X: pandas DataFrame with m rows and c columns
+    X: pd.DataFrame with m rows and c columns
         The time series data for the problem with m cases and c dimensions
     y: numpy array
         The class labels for each case in X
 
+    Examples
+    --------
+    >>> from sktime.datasets import load_arrow_head
+    >>> X, y = load_arrow_head()
+
     Notes
     -----
     Dimensionality:     univariate
@@ -397,8 +440,7 @@ def load_arrow_head(split=None, return_X_y=True, return_type="nested_univ"):
 
 
 def load_acsf1(split=None, return_X_y=True):
-    """
-    Load dataset on power consumption of typical appliances.
+    """Load dataset on power consumption of typical appliances.
 
     Parameters
     ----------
@@ -412,11 +454,16 @@ def load_acsf1(split=None, return_X_y=True):
 
     Returns
     -------
-    X: pandas DataFrame with m rows and c columns
+    X: pd.DataFrame with m rows and c columns
         The time series data for the problem with m cases and c dimensions
     y: numpy array
         The class labels for each case in X
 
+    Examples
+    --------
+    >>> from sktime.datasets import load_acsf1
+    >>> X, y = load_acsf1()
+
     Notes
     -----
     Dimensionality:     univariate
@@ -441,9 +488,13 @@ def load_acsf1(split=None, return_X_y=True):
     return _load_dataset(name, split, return_X_y)
 
 
-def load_basic_motions(split=None, return_X_y=True, return_type="nested_univ"):
+def load_basic_motions(split=None, return_X_y=True, return_type=None):
     """
-    Load the  BasicMotions time series classification problem and returns X and y.
+    Load the BasicMotions time series classification problem and returns X and y.
+
+    This is an equal length multivariate time series classification problem. It loads a
+    4 class classification problem with number of cases, n, where n = 80 (if
+    split is None) or 40 (if split is "train"/"test") of series length m = 100.
 
     Parameters
     ----------
@@ -451,17 +502,24 @@ def load_basic_motions(split=None, return_X_y=True, return_type="nested_univ"):
         Whether to load the train or test partition of the problem. By
         default it loads both.
     return_X_y: bool, optional (default=True)
-        If True, returns (features, target) separately instead of a single
-        dataframe with columns for
-        features and the target.
+        If True, returns (time series, target) separately as X and y instead of a single
+        data structure.
+    return_type: None or str{"numpy3d", "nested_univ"},
+        optional (default=None). Controls the returned data structure.
 
     Returns
     -------
-    X: pandas DataFrame with m rows and c columns
-        The time series data for the problem with m cases and c dimensions
-    y: numpy array
-        The class labels for each case in X
+    X:  The time series data for the problem. If return_type is either
+        "numpy2d"/"numpyflat", it returns 2D numpy array of shape (n,m), if "numpy3d" it
+        returns 3D numpy array of shape (n,6,m) and if "nested_univ" or None it returns
+        a nested pandas DataFrame of shape (n,6), where each cell is a pd.Series of
+        length m.
+    y: (optional) numpy array shape (n,1). The class labels for each case in X.
+        If return_X_y is False, y is appended to X.
 
+    Raises
+    ------
+    ValueError if argument "numpy2d"/"numpyflat" is passed as return_type
     Notes
     -----
     Dimensionality:     multivariate, 6
@@ -481,6 +539,12 @@ def load_basic_motions(split=None, return_X_y=True, return_type="nested_univ"):
     =BasicMotions
     """
     name = "BasicMotions"
+    if return_type == "numpy2d" or return_type == "numpyflat":
+        raise ValueError(
+            f"{name} loader: Error, attempting to load into a numpy2d "
+            f"array, but cannot because it is a multivariate problem. Use "
+            f"numpy3d instead"
+        )
     return _load_provided_dataset(
         name=name, split=split, return_X_y=return_X_y, return_type=return_type
     )
@@ -488,14 +552,18 @@ def load_basic_motions(split=None, return_X_y=True, return_type="nested_univ"):
 
 # forecasting data sets
 def load_shampoo_sales():
-    """
-    Load the shampoo sales univariate time series dataset for forecasting.
+    """Load the shampoo sales univariate time series dataset for forecasting.
 
     Returns
     -------
-    y : pandas Series/DataFrame
+    y : pd.Series/DataFrame
         Shampoo sales dataset
 
+    Examples
+    --------
+    >>> from sktime.datasets import load_shampoo_sales
+    >>> y = load_shampoo_sales()
+
     Notes
     -----
     This dataset describes the monthly number of sales of shampoo over a 3
@@ -507,7 +575,6 @@ def load_shampoo_sales():
     Frequency:          Monthly
     Number of cases:    1
 
-
     References
     ----------
     .. [1] Makridakis, Wheelwright and Hyndman (1998) Forecasting: methods
@@ -524,8 +591,7 @@ def load_shampoo_sales():
 
 
 def load_longley(y_name="TOTEMP"):
-    """
-    Load the Longley dataset for forecasting with exogenous variables.
+    """Load the Longley dataset for forecasting with exogenous variables.
 
     Parameters
     ----------
@@ -534,11 +600,16 @@ def load_longley(y_name="TOTEMP"):
 
     Returns
     -------
-    y: pandas.Series
+    y: pd.Series
         The target series to be predicted.
-    X: pandas.DataFrame
+    X: pd.DataFrame
         The exogenous time series data for the problem.
 
+    Examples
+    --------
+    >>> from sktime.datasets import load_longley
+    >>> y, X = load_longley()
+
     Notes
     -----
     This mulitvariate time series dataset contains various US macroeconomic
@@ -579,14 +650,18 @@ def load_longley(y_name="TOTEMP"):
 
 
 def load_lynx():
-    """
-    Load the lynx univariate time series dataset for forecasting.
+    """Load the lynx univariate time series dataset for forecasting.
 
     Returns
     -------
-    y : pandas Series/DataFrame
+    y : pd.Series/DataFrame
         Lynx sales dataset
 
+    Examples
+    --------
+    >>> from sktime.datasets import load_lynx
+    >>> y = load_lynx()
+
     Notes
     -----
     The annual numbers of lynx trappings for 1821–1934 in Canada. This
@@ -625,13 +700,17 @@ def load_lynx():
 
 
 def load_airline():
-    """
-    Load the airline univariate time series dataset [1].
+    """Load the airline univariate time series dataset [1].
 
     Returns
     -------
     y : pd.Series
-     Time series
+        Time series
+
+    Examples
+    --------
+    >>> from sktime.datasets import load_airline
+    >>> y = load_airline()
 
     Notes
     -----
@@ -648,7 +727,7 @@ def load_airline():
 
     References
     ----------
-    ..[1] Box, G. E. P., Jenkins, G. M. and Reinsel, G. C. (1976) Time Series
+    .. [1] Box, G. E. P., Jenkins, G. M. and Reinsel, G. C. (1976) Time Series
           Analysis, Forecasting and Control. Third Edition. Holden-Day.
           Series G.
     """
@@ -664,16 +743,20 @@ def load_airline():
 
 
 def load_uschange(y_name="Consumption"):
-    """
-    Load MTS dataset for forecasting Growth rates of personal consumption and income.
+    """Load MTS dataset for forecasting Growth rates of personal consumption and income.
 
     Returns
     -------
-    y : pandas Series
+    y : pd.Series
         selected column, default consumption
-    X : pandas Dataframe
+    X : pd.DataFrame
         columns with explanatory variables
 
+    Examples
+    --------
+    >>> from sktime.datasets import load_uschange
+    >>> y, X = load_uschange()
+
     Notes
     -----
     Percentage changes in quarterly personal consumption expenditure,
@@ -693,7 +776,7 @@ def load_uschange(y_name="Consumption"):
 
     References
     ----------
-    ..fpp2: Data for "Forecasting: Principles and Practice" (2nd Edition)
+    .. [1] Data for "Forecasting: Principles and Practice" (2nd Edition)
     """
     name = "Uschange"
     fname = name + ".csv"
@@ -705,7 +788,7 @@ def load_uschange(y_name="Consumption"):
     # data.index = pd.PeriodIndex(data.index, freq='Y')
     data = data.sort_values("Quarter")
     data = data.reset_index(drop=True)
-    data.index = pd.Int64Index(data.index)
+    data.index = pd.Index(data.index, dtype=int)
     data.name = name
     y = data[y_name]
     if y_name != "Quarter":
@@ -727,8 +810,6 @@ def load_gun_point_segmentation():
     temporal patterns but are approximate and limited to the values
     [10,20,50,100] to avoid over-fitting.
 
-    -----------
-
     Returns
     -------
         X : pd.Series
@@ -737,7 +818,11 @@ def load_gun_point_segmentation():
             The annotated period length by a human expert
         change_points : numpy array
             The change points annotated within the dataset
-    -----------
+
+    Examples
+    --------
+    >>> from sktime.datasets import load_gun_point_segmentation
+    >>> X, period_length, change_points = load_gun_point_segmentation()
     """
     dir = "segmentation"
     name = "GunPoint"
@@ -765,8 +850,6 @@ def load_electric_devices_segmentation():
     temporal patterns but are approximate and limited to the values
     [10,20,50,100] to avoid over-fitting.
 
-    -----------
-
     Returns
     -------
         X : pd.Series
@@ -775,7 +858,11 @@ def load_electric_devices_segmentation():
             The annotated period length by a human expert
         change_points : numpy array
             The change points annotated within the dataset
-    -----------
+
+    Examples
+    --------
+    >>> from sktime.datasets import load_electric_devices_segmentation
+    >>> X, period_length, change_points = load_electric_devices_segmentation()
     """
     dir = "segmentation"
     name = "ElectricDevices"
@@ -791,13 +878,18 @@ def load_electric_devices_segmentation():
 
 
 def load_PBS_dataset():
-    """Load the Pharmaceutical Benefit Scheme univariate time series dataset [1].
+    """Load the Pharmaceutical Benefit Scheme univariate time series dataset [1]_.
 
     Returns
     -------
     y : pd.Series
      Time series
 
+    Examples
+    --------
+    >>> from sktime.datasets import load_PBS_dataset
+    >>> y = load_PBS_dataset()
+
     Notes
     -----
     The Pharmaceutical Benefits Scheme (PBS) is the Australian government drugs
@@ -817,7 +909,7 @@ def load_PBS_dataset():
 
     References
     ----------
-    ..fpp3: Data for "Forecasting: Principles and Practice" (3rd Edition)
+    .. [1] Data for "Forecasting: Principles and Practice" (3rd Edition)
     """
     name = "PBS_dataset"
     fname = name + ".csv"
@@ -832,13 +924,18 @@ def load_PBS_dataset():
 
 def load_macroeconomic():
     """
-    Load the US Macroeconomic Data [1].
+    Load the US Macroeconomic Data [1]_.
 
     Returns
     -------
     y : pd.DataFrame
      Time series
 
+    Examples
+    --------
+    >>> from sktime.datasets import load_macroeconomic
+    >>> y = load_macroeconomic()
+
     Notes
     -----
     US Macroeconomic Data for 1959Q1 - 2009Q3.
